package com.example.hi_bugly;

import androidx.annotation.NonNull;

import com.tencent.bugly.crashreport.CrashReport;

import io.flutter.embedding.engine.plugins.FlutterPlugin;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;

/**
 * HiBuglyPlugin
 */
public class HiBuglyPlugin implements FlutterPlugin, MethodCallHandler {
    /// The MethodChannel that will the communication between Flutter and native Android
    ///
    /// This local reference serves to register the plugin with the Flutter Engine and unregister it
    /// when the Flutter Engine is detached from the Activity
    private MethodChannel channel;
    private FlutterPluginBinding flutterPluginBinding;

    @Override
    public void onAttachedToEngine(@NonNull FlutterPluginBinding flutterPluginBinding) {
        this.flutterPluginBinding = flutterPluginBinding;
        channel = new MethodChannel(flutterPluginBinding.getBinaryMessenger(), "hi_bugly");
        channel.setMethodCallHandler(this);
    }

    @Override
    public void onMethodCall(@NonNull MethodCall call, @NonNull Result result) {
        switch (call.method) {
            case "getPlatformVersion":
                result.success("Android " + android.os.Build.VERSION.RELEASE);
                break;
            case "initialize":
                String appID = "";
                boolean debug = false;
                if (call.hasArgument("appID")) {
                    appID = call.argument("appID");
                }
                if (call.hasArgument("debug")) {
                    debug = Boolean.TRUE.equals(call.argument("debug"));
                }
                CrashReport.initCrashReport(flutterPluginBinding.getApplicationContext(), appID, debug);
                result.success(true);
                break;
            case "postException":
                String message = "";
                if (call.hasArgument("message")) {
                    message = call.argument("message");
                }
                CrashReport.postCatchedException(new Throwable(message));
                break;
            default:
                result.notImplemented();
                break;
        }
    }

    @Override
    public void onDetachedFromEngine(@NonNull FlutterPluginBinding binding) {
        channel.setMethodCallHandler(null);
    }
}
