#import "HiBuglyPlugin.h"
#import <Bugly/Bugly.h>

@implementation HiBuglyPlugin
+ (void)registerWithRegistrar:(NSObject<FlutterPluginRegistrar>*)registrar {
    FlutterMethodChannel* channel = [FlutterMethodChannel
                                     methodChannelWithName:@"hi_bugly"
                                     binaryMessenger:[registrar messenger]];
    HiBuglyPlugin* instance = [[HiBuglyPlugin alloc] init];
    [registrar addMethodCallDelegate:instance channel:channel];
}

- (void)handleMethodCall:(FlutterMethodCall*)call result:(FlutterResult)result {
    NSString *method = call.method;
    if ([method isEqualToString:@"initialize"]) {
        NSString *appID = call.arguments[@"appID"];
        BOOL debug = call.arguments[@"debug"];
        BuglyConfig *config = [[BuglyConfig alloc] init];
        config.debugMode = debug;
        [Bugly startWithAppId:appID config: config];
        result([NSNumber numberWithBool:YES]);
    }
    else if ([method isEqualToString:@"postException"]) {
        NSString *name = call.arguments[@"name"];
        NSString *reason = call.arguments[@"reason"];
        // 此调用栈为 dart 调用栈，放入扩展信息
        NSString *callStack = call.arguments[@"callStack"];
        NSString *extraInfo = call.arguments[@"extraInfo"];
        [Bugly reportExceptionWithCategory: 3
                                      name:name
                                    reason:reason
                                 callStack:@[]
                                 extraInfo:@{
            @"dartCallStack" : callStack,
            @"extraInfo": extraInfo,
          }
                              terminateApp:NO];
      }
      else {
          result(FlutterMethodNotImplemented);
      }
}

@end
